@@ -17,6 +17,7 @@
 #include <ktexteditor/movingcursor.h>
 
 #include <QScrollBar>
+#include <QSignalSpy>
 #include <QStandardPaths>
 #include <QTemporaryFile>
 #include <QtTestWidgets>
@@ -154,6 +155,20 @@ void KateViewTest::testLowerCaseBlockSelection()
     QCOMPARE(doc.text(), QStringLiteral("ny\nnyy\n"));
 }
 
+void KateViewTest::testIndentBlockSelection()
+{
+    KTextEditor::DocumentPrivate doc;
+    doc.setText(QStringLiteral("nY\nnYY\n"));
+
+    KTextEditor::ViewPrivate *view1 = new KTextEditor::ViewPrivate(&doc, nullptr);
+    view1->setSelection(Range(0, 0, 2, 0));
+    view1->setBlockSelection(true);
+    view1->indent();
+    QCOMPARE(doc.text(), QStringLiteral("    nY\n    nYY\n    "));
+    view1->unIndent();
+    QCOMPARE(doc.text(), QStringLiteral("nY\nnYY\n"));
+}
+
 namespace
 {
 QWidget *findViewInternal(KTextEditor::View *view)
@@ -744,4 +759,34 @@ void KateViewTest::testUpdateFoldingMarkersHighlighting()
     QCOMPARE(foldingMarkerEnd->toRange(), firstDoMatching);
 }
 
+void KateViewTest::testDdisplayRangeChangedEmitted()
+{
+    KTextEditor::DocumentPrivate doc(false, false);
+    doc.setText(QStringList(250, QStringLiteral("Hello world")));
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    view->resize(300, 300);
+    QSignalSpy spy(view, &KTextEditor::View::displayRangeChanged);
+    view->setCursorPosition({180, 0});
+    QVERIFY(spy.count() == 1);
+}
+
+void KateViewTest::testCrashOnPasteInOverwriteMode()
+{
+    // create doc with a few lines
+    KTextEditor::DocumentPrivate doc(false, false);
+    const QString testText(QStringLiteral("test1\ntest2\ntest3\n"));
+    doc.setText(testText);
+
+    // create view in overwrite mode
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    view->doc()->config()->setOvr(true);
+
+    // simulate paste at end of document that did crash, bug 496612
+    view->setCursorPosition(KTextEditor::Cursor(2, 0));
+    view->paste(&testText);
+
+    // check result is ok
+    QCOMPARE(doc.text(), QStringLiteral("test1\ntest2\ntest1\ntest2\ntest3\n"));
+}
+
 // kate: indent-mode cstyle; indent-width 4; replace-tabs on;
